searchNodes=[{"doc":"Litmus is a data validation library for Elixir.","ref":"Litmus.html","title":"Litmus","type":"module"},{"doc":"Validates and converts data based on a schema.Examplesiex&gt; Litmus.validate(%{&quot;id&quot; =&gt; &quot;123&quot;}, %{&quot;id&quot; =&gt; %Litmus.Type.Number{}}) {:ok, %{&quot;id&quot; =&gt; 123}} iex&gt; Litmus.validate(%{&quot;id&quot; =&gt; &quot;asdf&quot;}, %{&quot;id&quot; =&gt; %Litmus.Type.Number{}}) {:error, &quot;id must be a number&quot;}","ref":"Litmus.html#validate/2","title":"Litmus.validate/2","type":"function"},{"doc":"This type provides validation for any type of value.Options:default - Setting :default will populate a field with the provided value, assuming that it is not present already. If a field already has a value present, it will not be altered.:required - Setting :required to true will cause a validation error when a field is not present or the value is nil. Allowed values for required are true and false. The default is false.Examplesiex&gt; schema = %{&quot;id&quot; =&gt; %Litmus.Type.Any{required: true}} iex&gt; Litmus.validate(%{&quot;id&quot; =&gt; 1}, schema) {:ok, %{&quot;id&quot; =&gt; 1}} iex&gt; schema = %{&quot;id&quot; =&gt; %Litmus.Type.Any{default: &quot;new_id&quot;}} iex&gt; Litmus.validate(%{}, schema) {:ok, %{&quot;id&quot; =&gt; &quot;new_id&quot;}} iex&gt; schema = %{&quot;id&quot; =&gt; %Litmus.Type.Any{required: true}} iex&gt; Litmus.validate(%{}, schema) {:error, &quot;id is required&quot;} iex&gt; schema = %{&quot;id&quot; =&gt; %Litmus.Type.Any{required: true}} iex&gt; Litmus.validate(%{&quot;id&quot; =&gt; nil}, schema) {:error, &quot;id is required&quot;}","ref":"Litmus.Type.Any.html","title":"Litmus.Type.Any","type":"module"},{"doc":"","ref":"Litmus.Type.Any.html#validate_field/3","title":"Litmus.Type.Any.validate_field/3","type":"function"},{"doc":"","ref":"Litmus.Type.Any.html#t:t/0","title":"Litmus.Type.Any.t/0","type":"type"},{"doc":"This type validates and converts values to booleans. It converts truthy and falsy values to true or false.Options:default - Setting :default will populate a field with the provided value, assuming that it is not present already. If a field already has a value present, it will not be altered.:required - Setting :required to true will cause a validation error when a field is not present or the value is nil. Allowed values for required are true and false. The default is false.:truthy - Allows additional values, i.e. truthy values to be considered valid booleans by converting them to true during validation. Allowed value is an array of strings, numbers, or booleans. The default is [true, &quot;true&quot;]:falsy - Allows additional values, i.e. falsy values to be considered valid booleans by converting them to false during validation. Allowed value is an array of strings, number or boolean values. The default is [false, &quot;false&quot;]Examplesiex&gt; schema = %{ ...&gt; &quot;new_user&quot; =&gt; %Litmus.Type.Boolean{ ...&gt; truthy: [&quot;1&quot;], ...&gt; falsy: [&quot;0&quot;] ...&gt; } ...&gt; } iex&gt; params = %{&quot;new_user&quot; =&gt; &quot;1&quot;} iex&gt; Litmus.validate(params, schema) {:ok, %{&quot;new_user&quot; =&gt; true}} iex&gt; schema = %{ ...&gt; &quot;new_user&quot; =&gt; %Litmus.Type.Boolean{ ...&gt; default: false ...&gt; } ...&gt; } iex&gt; Litmus.validate(%{}, schema) {:ok, %{&quot;new_user&quot; =&gt; false}} iex&gt; schema = %{&quot;new_user&quot; =&gt; %Litmus.Type.Boolean{}} iex&gt; params = %{&quot;new_user&quot; =&gt; 0} iex&gt; Litmus.validate(params, schema) {:error, &quot;new_user must be a boolean&quot;}","ref":"Litmus.Type.Boolean.html","title":"Litmus.Type.Boolean","type":"module"},{"doc":"","ref":"Litmus.Type.Boolean.html#validate_field/3","title":"Litmus.Type.Boolean.validate_field/3","type":"function"},{"doc":"","ref":"Litmus.Type.Boolean.html#t:t/0","title":"Litmus.Type.Boolean.t/0","type":"type"},{"doc":"This type validates DateTimes. It accepts either DateTime structs or ISO-8601 strings. ISO-8601 datetime with timezone strings will be converted into DateTimes.Options:default - Setting :default will populate a field with the provided value, assuming that it is not present already. If a field already has a value present, it will not be altered.:required - Setting :required to true will cause a validation error when a field is not present or the value is nil. Allowed values for required are true and false. The default is false.Examplesiex&gt; schema = %{&quot;start_date&quot; =&gt; %Litmus.Type.DateTime{}} iex&gt; {:ok, %{&quot;start_date&quot; =&gt; datetime}} = Litmus.validate(%{&quot;start_date&quot; =&gt; &quot;2017-06-18T05:45:33Z&quot;}, schema) iex&gt; DateTime.to_iso8601(datetime) &quot;2017-06-18T05:45:33Z&quot; iex&gt; {:ok, default_datetime, _} = DateTime.from_iso8601(&quot;2019-05-01T06:25:00-0700&quot;) ...&gt; schema = %{ ...&gt; &quot;start_date&quot; =&gt; %Litmus.Type.DateTime{ ...&gt; default: default_datetime ...&gt; } ...&gt; } iex&gt; {:ok, %{&quot;start_date&quot; =&gt; datetime}} = Litmus.validate(%{}, schema) iex&gt; DateTime.to_iso8601(datetime) &quot;2019-05-01T13:25:00Z&quot;","ref":"Litmus.Type.DateTime.html","title":"Litmus.Type.DateTime","type":"module"},{"doc":"","ref":"Litmus.Type.DateTime.html#validate_field/3","title":"Litmus.Type.DateTime.validate_field/3","type":"function"},{"doc":"","ref":"Litmus.Type.DateTime.html#t:t/0","title":"Litmus.Type.DateTime.t/0","type":"type"},{"doc":"This type validates that a value is list.Options:default - Setting :default will populate a field with the provided value, assuming that it is not present already. If a field already has a value present, it will not be altered.:min_length - Specifies the minimum list length. Allowed values are non-negative integers.:max_length - Specifies the maximum list length. Allowed values are non-negative integers.:length - Specifies the exact list length. Allowed values are non-negative integers.:required - Setting :required to true will cause a validation error when a field is not present or the value is nil. Allowed values for required are true and false. The default is false.:type - Specifies the data type of elements in the list. Allowed values are are atoms :atom, :boolean, :number and :string. Default value is nil. If nil, any element type is allowed in the list.:unique - Setting :unique to true will validate that all values in the list are unique. The default value is false.Examplesiex&gt; schema = %{ ...&gt; &quot;ids&quot; =&gt; %Litmus.Type.List{ ...&gt; min_length: 1, ...&gt; max_length: 5, ...&gt; type: :number ...&gt; } ...&gt; } iex&gt; Litmus.validate(%{&quot;ids&quot; =&gt; [1, 2]}, schema) {:ok, %{&quot;ids&quot; =&gt; [1, 2]}} iex&gt; Litmus.validate(%{&quot;ids&quot; =&gt; [1, &quot;a&quot;]}, schema) {:error, &quot;ids must be a list of numbers&quot;} iex&gt; schema = %{ ...&gt; &quot;ids&quot; =&gt; %Litmus.Type.List{ ...&gt; default: [] ...&gt; } ...&gt; } iex&gt; Litmus.validate(%{}, schema) {:ok, %{&quot;ids&quot; =&gt; []}}","ref":"Litmus.Type.List.html","title":"Litmus.Type.List","type":"module"},{"doc":"","ref":"Litmus.Type.List.html#validate_field/3","title":"Litmus.Type.List.validate_field/3","type":"function"},{"doc":"","ref":"Litmus.Type.List.html#t:t/0","title":"Litmus.Type.List.t/0","type":"type"},{"doc":"This type validates that values are numbers, and converts them to numbers if possible. It converts &quot;stringified&quot; numerical values to numbers.Options:default - Setting :default will populate a field with the provided value, assuming that it is not present already. If a field already has a value present, it will not be altered.:min - Specifies the minimum value of the field.:max - Specifies the maximum value of the field.:integer - Specifies that the number must be an integer (no floating point). Allowed values are true and false. The default is false.:required - Setting :required to true will cause a validation error when a field is not present or the value is nil. Allowed values for required are true and false. The default is false.Examplesiex&gt; schema = %{ ...&gt; &quot;id&quot; =&gt; %Litmus.Type.Number{ ...&gt; integer: true ...&gt; }, ...&gt; &quot;gpa&quot; =&gt; %Litmus.Type.Number{ ...&gt; min: 0, ...&gt; max: 4 ...&gt; } ...&gt; } iex&gt; params = %{&quot;id&quot; =&gt; &quot;123&quot;, &quot;gpa&quot; =&gt; 3.8} iex&gt; Litmus.validate(params, schema) {:ok, %{&quot;id&quot; =&gt; 123, &quot;gpa&quot; =&gt; 3.8}} iex&gt; params = %{&quot;id&quot; =&gt; &quot;123.456&quot;, &quot;gpa&quot; =&gt; 3.8} iex&gt; Litmus.validate(params, schema) {:error, &quot;id must be an integer&quot;} iex&gt; schema = %{ ...&gt; &quot;gpa&quot; =&gt; %Litmus.Type.Number{ ...&gt; default: 4 ...&gt; } ...&gt; } iex&gt; Litmus.validate(%{}, schema) {:ok, %{&quot;gpa&quot; =&gt; 4}}","ref":"Litmus.Type.Number.html","title":"Litmus.Type.Number","type":"module"},{"doc":"","ref":"Litmus.Type.Number.html#validate_field/3","title":"Litmus.Type.Number.validate_field/3","type":"function"},{"doc":"","ref":"Litmus.Type.Number.html#t:t/0","title":"Litmus.Type.Number.t/0","type":"type"},{"doc":"This type validates and converts values to strings It converts boolean and number values to strings.Options:default - Setting :default will populate a field with the provided value, assuming that it is not present already. If a field already has a value present, it will not be altered.:min_length - Specifies the minimum number of characters allowed in the string. Allowed values are non-negative integers.:max_length - Specifies the maximum number of characters allowed in the string. Allowed values are non-negative integers.:length - Specifies the exact number of characters allowed in the string. Allowed values are non-negative integers.:regex - Specifies a Regular expression that a string must match. Use the Litmus.Type.String.Regex struct with the options::pattern - A Regex.t() to match:error_message - An error message to use when the pattern does not match:replace - Replaces occurences of a pattern with a string. Use the Litmus.Type.String.Replace struct with the options::pattern - A Regex.t(), String.t(), or compiled pattern to match:replacement - A String.t() to replace:global - When true, all occurences of the pattern are replaced. When false, only the first occurence is replaced. Defaults to true.:required - Setting :required to true will cause a validation error when a field is not present or the value is nil. Allowed values for required are true and false. The default is false.:trim - Removes additional whitespace at the front and end of a string. Allowed values are true and false. The default is false.Examplesiex&gt; schema = %{ ...&gt; &quot;username&quot; =&gt; %Litmus.Type.String{ ...&gt; min_length: 3, ...&gt; max_length: 10, ...&gt; trim: true ...&gt; }, ...&gt; &quot;password&quot; =&gt; %Litmus.Type.String{ ...&gt; length: 6, ...&gt; regex: %Litmus.Type.String.Regex{ ...&gt; pattern: ~r/^[a-zA-Z0-9_]*$/, ...&gt; error_message: &quot;password must be alphanumeric&quot; ...&gt; } ...&gt; } ...&gt; } iex&gt; params = %{&quot;username&quot; =&gt; &quot; user123 &quot;, &quot;password&quot; =&gt; &quot;root01&quot;} iex&gt; Litmus.validate(params, schema) {:ok, %{&quot;username&quot; =&gt; &quot;user123&quot;, &quot;password&quot; =&gt; &quot;root01&quot;}} iex&gt; Litmus.validate(%{&quot;password&quot; =&gt; &quot;ro!_@1&quot;}, schema) {:error, &quot;password must be alphanumeric&quot;} iex&gt; schema = %{ ...&gt; &quot;username&quot; =&gt; %Litmus.Type.String{ ...&gt; replace: %Litmus.Type.String.Replace{ ...&gt; pattern: ~r/_/, ...&gt; replacement: &quot;&quot; ...&gt; } ...&gt; } ...&gt; } iex&gt; Litmus.validate(%{&quot;username&quot; =&gt; &quot;one_two_three&quot;}, schema) {:ok, %{&quot;username&quot; =&gt; &quot;onetwothree&quot;}} iex&gt; schema = %{ ...&gt; &quot;username&quot; =&gt; %Litmus.Type.String{ ...&gt; default: &quot;anonymous&quot; ...&gt; } ...&gt; } iex&gt; Litmus.validate(%{}, schema) {:ok, %{&quot;username&quot; =&gt; &quot;anonymous&quot;}}","ref":"Litmus.Type.String.html","title":"Litmus.Type.String","type":"module"},{"doc":"","ref":"Litmus.Type.String.html#validate_field/3","title":"Litmus.Type.String.validate_field/3","type":"function"},{"doc":"","ref":"Litmus.Type.String.html#t:t/0","title":"Litmus.Type.String.t/0","type":"type"},{"doc":"Litmus Data validation in Elixir","ref":"readme.html","title":"Litmus","type":"extras"},{"doc":"The package can be installed by adding litmus to your list of dependencies in mix.exs:def deps do [ {:litmus, &quot;~&gt; 1.0.1&quot;} ] end","ref":"readme.html#installation","title":"Litmus - Installation","type":"extras"},{"doc":"Litmus validates data against a predefined schema with the Litmus.validate/2 function.If the data is valid, the function returns {:ok, data}. The data returned will be coerced according to the provided schema.If the data passed does not follow the rules defined in the schema, the function returns {:error, error_message}. It will also return an error when receiving a field that has not been specified in the provided schema.schema = %{ &quot;id&quot; =&gt; %Litmus.Type.Any{ required: true }, &quot;username&quot; =&gt; %Litmus.Type.String{ min_length: 6, required: true }, &quot;pin&quot; =&gt; %Litmus.Type.Number{ min: 1000, max: 9999, required: true }, &quot;new_user&quot; =&gt; %Litmus.Type.Boolean{ truthy: [&quot;1&quot;], falsy: [&quot;0&quot;] }, &quot;account_ids&quot; =&gt; %Litmus.Type.List{ max_length: 3, type: :number }, &quot;remember_me&quot; =&gt; %Litmus.Type.Boolean{ default: false } } params = %{ &quot;id&quot; =&gt; 1, &quot;username&quot; =&gt; &quot;user@123&quot;, &quot;pin&quot; =&gt; 1234, &quot;new_user&quot; =&gt; &quot;1&quot;, &quot;account_ids&quot; =&gt; [1, 3, 9] } Litmus.validate(params, schema) # =&gt; {:ok, # %{ # &quot;id&quot; =&gt; 1, # &quot;new_user&quot; =&gt; true, # &quot;pin&quot; =&gt; 1234, # &quot;username&quot; =&gt; &quot;user@123&quot;, # &quot;account_ids&quot; =&gt; [1, 3, 9], # &quot;remember_me&quot; =&gt; false # } # } Litmus.validate(%{}, schema) # =&gt; {:error, &quot;id is required&quot;}","ref":"readme.html#usage","title":"Litmus - Usage","type":"extras"},{"doc":"Litmus currently supports the following types.Litmus.Type.AnyLitmus.Type.BooleanLitmus.Type.DateTimeLitmus.Type.ListLitmus.Type.NumberLitmus.Type.String","ref":"readme.html#supported-types","title":"Litmus - Supported Types","type":"extras"},{"doc":"Litmus comes with a Plug for easy integration with Plug's built-in router. You can automatically validate query parameters and body parameters by passing the litmus_query and litmus_body private options to each route. When declaring the plug you must include a on_error/2 function to be called when validation fails. It is recommended that you initialize this Plug between the :match and :dispatch plugs. If you want processing to stop on a validation error, be sure to halt the request with Plug.Conn.halt/1.Exampledefmodule MyRouter do use Plug.Router plug(Plug.Parsers, parsers: [:urlencoded, :multipart]) plug(:match) plug(Litmus.Plug, on_error: &amp;__MODULE__.on_error/2) plug(:dispatch) @schema %{ &quot;id&quot; =&gt; %Litmus.Type.Number{ required: true } } get &quot;/test&quot;, private: %{litmus_query: @schema} do Plug.Conn.send_resp(conn, 200, &quot;items&quot;) end post &quot;/test&quot;, private: %{litmus_body: @schema} do Plug.Conn.send_resp(conn, 200, &quot;items&quot;) end def on_error(conn, error_message) do conn |&gt; Plug.Conn.send_resp(400, error_message) |&gt; Plug.Conn.halt() end end","ref":"readme.html#plug-integration","title":"Litmus - Plug Integration","type":"extras"}]